@@ -5,7 +5,7 @@ import re
 import warnings
 from enum import Enum, EnumMeta
 from typing import Tuple
-from dataclasses import dataclass, asdict
+from dataclasses import dataclass, asdict, field
 
 from aenum import extend_enum
 
@@ -21,6 +21,7 @@ class _CollectionType:
     SENTINEL2 = 'Sentinel-2'
     SENTINEL3 = 'Sentinel-3'
     SENTINEL5P = 'Sentinel-5P'
+    LANDSAT15 = 'Landsat 1-5'
     LANDSAT45 = 'Landsat 4-5'
     LANDSAT5 = 'Landsat 5'
     LANDSAT7 = 'Landsat 7'
@@ -39,6 +40,8 @@ class _SensorType:
     MSI = 'MSI'
     OLI_TIRS = 'OLI-TIRS'
     TM = 'TM'
+    ETM = 'ETM+'
+    MSS = 'MSS'
     C_SAR = 'C-SAR'
     OLCI = 'OLCI'
     SLSTR = 'SLSTR'
@@ -110,7 +113,10 @@ class _Bands:
     SENTINEL5P = ('AER_AI_340_380', 'AER_AI_354_388', 'CLOUD_BASE_HEIGHT', 'CLOUD_BASE_PRESSURE', 'CLOUD_FRACTION',
                   'CLOUD_OPTICAL_THICKNESS', 'CLOUD_TOP_HEIGHT', 'CLOUD_TOP_PRESSURE', 'CO', 'HCHO', 'NO2', 'O3',
                   'SO2', 'CH4')
+    LANDSAT15 = ('B01', 'B02', 'B03', 'B04')
     LANDSAT45 = ('B01', 'B02', 'B03', 'B04', 'B05', 'B06', 'B07')
+    LANDSAT7_L1 = ('B01', 'B02', 'B03', 'B04', 'B05', 'B06_VCID1', 'B06_VCID2', 'B07', 'B08')
+    LANDSAT7_L2 = ('B01', 'B02', 'B03', 'B04', 'B05', 'B06', 'B07')
     LANDSAT8 = ('B01', 'B02', 'B03', 'B04', 'B05', 'B06', 'B07', 'B08', 'B09', 'B10', 'B11')
     LANDSAT8_L2 = ('B01', 'B02', 'B03', 'B04', 'B05', 'B06', 'B07', 'B10')
     DEM = ('DEM',)
@@ -125,6 +131,10 @@ class _DataCollectionMeta(EnumMeta):
 
         This implements a shortcut to create a BYOC data collection by calling DataCollection('<BYOC collection ID>')
         """
+        # This solves a problem of pickling a custom DataCollection and unpickling it in another process
+        if isinstance(value, DataCollectionDefinition) and value not in cls._value2member_map_ and value._name:
+            cls._try_add_data_collection(value._name, value)
+
         # pylint: disable=signature-differs
         if not isinstance(value, str):
             return super().__call__(value, *args, **kwargs)
@@ -161,6 +171,8 @@ class DataCollectionDefinition:
     is_timeless: bool = False
     has_cloud_coverage: bool = False
     dem_instance: str = None
+    # The following parameter is used to preserve custom DataCollection name during pickling and unpickling process:
+    _name: str = field(default=None, compare=False)
 
     def __post_init__(self):
         """ In case a list of bands has been given this makes sure to cast it into a tuple
@@ -172,7 +184,7 @@ class DataCollectionDefinition:
         """ A nicer representation of parameters that define a data collection
         """
         valid_params = {name: value for name, value in asdict(self).items() if value is not None}
-        params_repr = '\n  '.join(f'{name}: {value}' for name, value in valid_params.items())
+        params_repr = '\n  '.join(f'{name}: {value}' for name, value in valid_params.items() if name != '_name')
         return f'{self.__class__.__name__}(\n  {params_repr}\n)'
 
     def derive(self, **params):
@@ -287,6 +299,18 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
         bands=_Bands.MODIS
     )
 
+    LANDSAT15_L1 = DataCollectionDefinition(
+        api_id='landsat-mss-l1',
+        catalog_id='landsat-mss-l1',
+        wfs_id='DSS14',
+        service_url=ServiceUrl.USWEST,
+        collection_type=_CollectionType.LANDSAT15,
+        sensor_type=_SensorType.MSS,
+        processing_level=_ProcessingLevel.L1,
+        bands=_Bands.LANDSAT15,
+        has_cloud_coverage=True
+    )
+
     LANDSAT45_L1 = DataCollectionDefinition(
         api_id='landsat-tm-l1',
         catalog_id='landsat-tm-l1',
@@ -305,6 +329,25 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
         processing_level=_ProcessingLevel.L2
     )
 
+    LANDSAT7_L1 = DataCollectionDefinition(
+        api_id='landsat-etm-l1',
+        catalog_id='landsat-etm-l1',
+        wfs_id='DSS17',
+        service_url=ServiceUrl.USWEST,
+        collection_type=_CollectionType.LANDSAT7,
+        sensor_type=_SensorType.ETM,
+        processing_level=_ProcessingLevel.L1,
+        bands=_Bands.LANDSAT7_L1,
+        has_cloud_coverage=True
+    )
+    LANDSAT7_L2 = LANDSAT7_L1.derive(
+        api_id='landsat-etm-l2',
+        catalog_id='landsat-etm-l2',
+        wfs_id='DSS18',
+        processing_level=_ProcessingLevel.L2,
+        bands=_Bands.LANDSAT7_L2
+    )
+
     LANDSAT8 = DataCollectionDefinition(
         api_id='landsat-8-l1c',
         catalog_id='landsat-8-l1c',
@@ -447,7 +490,8 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
             collection_id=collection_id,
             is_timeless=is_timeless,
             has_cloud_coverage=has_cloud_coverage,
-            dem_instance=dem_instance
+            dem_instance=dem_instance,
+            _name=name
         )
         cls._try_add_data_collection(name, definition)
         return cls(definition)
@@ -462,7 +506,7 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
         :rtype: DataCollection
         """
         definition = self.value
-        new_definition = definition.derive(**params)
+        new_definition = definition.derive(**params, _name=name)
 
         self._try_add_data_collection(name, new_definition)
         return DataCollection(new_definition)
